import click

from mosamatic.tasks import CreatePngsFromSegmentationsTask
from mosamatic.utils import param_dict_from_params


@click.command(help='Create PNG images from segmentation files')
@click.option(
    '--segmentations_dir', 
    required=True, 
    type=click.Path(exists=True), 
    help='Input directory to segmentation files'
)
@click.option(
    '--output_dir', 
    required=True, 
    type=click.Path(), 
    help='Output directory for PNG images'
)
@click.option(
    '--fig_width', 
    type=click.Path(), 
    default=10,
    help='Figure width (default: 10)'
)
@click.option(
    '--fig_height', 
    type=click.Path(), 
    default=10,
    help='Figure height (default: 10)'
)
@click.option(
    '--overwrite', 
    type=click.BOOL, 
    default=False, 
    help='Overwrite (true/false)'
)
def createpngsfromsegmentations(segmentations_dir, output_dir, fig_width, fig_height, overwrite):
    """
    Creates PNG images from segmentations files generated by the "segmentmusclefatl3" command.
    
    Parameters
    ----------
    segmentations_dir : str
        Path to directory with segmentation files.
    
    output_dir : str
        Path to output directory where PNG images will be stored.

    fig_width: int
        Figure width of PNG image (default: 10)
    
    fig_height: int
        Figure height of PNG image (default: 10)
    
    overwrite : bool
        Overwrite contents output directory true/false
    """
    task = CreatePngsFromSegmentationsTask(segmentations_dir, output_dir, fig_width, fig_height, overwrite)
    task.run()